import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '../views/layout/Layout'
import LayoutUser from '../views/layout/layoutUser'

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    roles: ['admin','editor']     will control the page roles (you can set multiple roles)
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
    noCache: true                if true ,the page will no be cached(default is false)
  }
**/

// 所有权限通用路由表
// 如首页和登录页和一些不用权限的公用页面

export const constantRouterMap = [
  { path: '/login', component: () => import('@/views/login/index'), hidden: true },
  { path: '/404', component: () => import('@/views/404'), hidden: true },
  {
    path: '/',
    component: LayoutUser,
    redirect: '/home',
    hidden: true,
    children: [{
      path: '/home',
      component: () => import('@/views/home/unloginHome'),
      name: 'home',
      meta: { title: '首页' }
    }]
  }
]

// 实例化vue的时候只挂载constantRouter

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})

// 异步挂载的路由
// 动态需要根据权限加载的路由表

export const asyncRouterMapGeneralUser = [
  {
    path: '',
    component: LayoutUser,
    hidden: true,
    children: [{
      path: '/loginedHome',
      component: () => import('@/views/home/loginedHome'),
      name: 'loginedHome',
      meta: { title: '主页' }
    }]
  },
  {
    path: '',
    component: LayoutUser,
    hidden: true,
    children: [{
      path: '/realtimeMonitor',
      component: () => import('@/views/timeMonitoring/index'),
      name: 'realtimeMonitor',
      meta: { title: '实时监测' }
    }]
  },
  { path: '*', redirect: '/404', hidden: true }
]

export const asyncRouterMapAdmin = [
  {
    path: '',
    component: Layout,
    name: 'peoplesManage',
    meta: {
      title: '',
      roles: ['1']
    },
    alwaysShow: false,
    children: [
      {
        path: 'infoManage',
        name: 'infoManage',
        component: () => import('@/views/peoplesManage/infoManage/index'),
        meta: { title: '用户信息管理', icon: 'peoples' }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    name: 'bridgeManage',
    meta: {
      roles: ['1']
    },
    alwaysShow: false,
    children: [
      {
        path: 'bridgesInfo',
        name: 'BridgesInfo',
        component: () => import('@/views/baseInfoManage/bridgesInfo/index'),
        meta: { title: '站点信息管理', icon: 'site' }
      }
    ]
  }, { path: '*', redirect: '/404', hidden: true }
]
